==> custom_pages-v1.12.5.zip: custom_pages/messages/fr/model.php <==
<?php

return [
    'Abstract' => 'Résumé',
    'Activate PHP based Pages and Snippets' => 'Activer les pages et les fragments de page basés sur du PHP',
    'Attach Files' => 'Transférer des fichiers',
    'Content' => 'Contenu',
    'Empty <br />Container' => 'Conteneur vide<br />',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Si désactivé, les pages PHP existantes seront toujours en ligne, mais il ne sera pas possible d\'en créer de nouvelles.',
    'Label' => 'Libellé',
    'Open in new window' => 'Ouvrir dans une nouvelle fenêtre',
    'PHP view path for custom space pages' => 'Chemin de la vue PHP pour les pages d\'espace personnalisées',
    'PHP view path for custom space snippets' => 'Chemin de la vue PHP pour les fragments de page d\'espace personnalisés',
    'PHP view path for global custom pages' => 'Chemin de la vue PHP pour les pages générales personnalisées',
    'PHP view path for global custom snippets' => 'Chemin de la vue PHP pour les fragments de page générale personnalisés',
    'Placeholder name' => 'Nom de l\'espace réservé',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Le nom de l\'élément doit contenir au moins deux caractères sans espace ou caractère spécial à l\'exception du caractère "_"',
    'The given element name is already in use for this template.' => 'Le nom donné pour l\'élément est déjà utilisé dans ce modèle.',
    'The given view file path does not exist.' => 'Le chemin donné du fichier de vue n\'existe pas.',
    'Url shortcut' => 'Raccourci',
    'View' => 'Afficher',
    'Visibility' => 'Visibilité',
    'page' => 'page',
    'snippet' => 'extrait',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/fr/model.php <==
<?php

return [
    'Abstract' => 'Résumé',
    'Activate PHP based Pages and Snippets' => 'Activer les pages et les fragments de page basés sur du PHP',
    'Attach Files' => 'Transférer des fichiers',
    'Content' => 'Contenu',
    'Empty <br />Container' => 'Conteneur vide<br />',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Si désactivé, les pages PHP existantes seront toujours en ligne, mais il ne sera pas possible d\'en créer de nouvelles.',
    'Label' => 'Libellé',
    'Open in new window' => 'Ouvrir dans une nouvelle fenêtre',
    'PHP view path for custom space pages' => 'Chemin de la vue PHP pour les pages d\'espace personnalisées',
    'PHP view path for custom space snippets' => 'Chemin de la vue PHP pour les fragments de page d\'espace personnalisés',
    'PHP view path for global custom pages' => 'Chemin de la vue PHP pour les pages générales personnalisées',
    'PHP view path for global custom snippets' => 'Chemin de la vue PHP pour les fragments de page générale personnalisés',
    'Placeholder name' => 'Nom de l\'espace réservé',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Le nom de l\'élément doit contenir au moins deux caractères sans espace ou caractère spécial à l\'exception du caractère "_"',
    'The given element name is already in use for this template.' => 'Le nom donné pour l\'élément est déjà utilisé dans ce modèle.',
    'The given view file path does not exist.' => 'Le chemin donné du fichier de vue n\'existe pas.',
    'Url shortcut' => 'Raccourci',
    'View' => 'Afficher',
    'Visibility' => 'Visibilité',
    'page' => 'page',
    'snippet' => 'extrait',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
